@@ -2,7 +2,7 @@ package Test::Pretty;
 use strict;
 use warnings;
 use 5.008001;
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use Test::Builder 0.82;
 use Term::Encoding ();
@@ -128,6 +128,12 @@ END {
     my $builder = Test::Builder->new;
     my $real_exit_code = $?;
     if ($SHOW_DUMMY_TAP && !$real_exit_code) {
+        if ($builder->{Have_Plan}) {
+            if ($builder->{Curr_Test} != $builder->{Expected_Tests}) {
+                $builder->diag("Bad plan: $builder->{Curr_Test} != $builder->{Expected_Tests}");
+                $builder->is_passing(0);
+            }
+        }
         printf("\n%s\n", $builder->is_passing ? 'ok' : 'not ok');
         if ($builder->is_passing) {
             ## no critic (Variables::RequireLocalizedPunctuationVars)
@@ -264,7 +270,10 @@ sub _subtest {
     };
     $builder->_indent($orig_indent . '    ');
     my $curr_test = $builder->{Curr_Test};
-    my $retval = $code->();
+    my $retval = do {
+        local $builder->{Have_Plan}; # this is bad, but works.
+        $code->();
+    };
     if ($curr_test == $builder->{Curr_Test}) {
         # no tests run in subtest.
         $builder->diag("There is no test case in subtest");
@@ -299,7 +308,7 @@ sub _expected_tests {
           unless $max =~ /^\+?\d+$/;
 
         $self->{Expected_Tests} += $max;
-        $self->{Have_Plan}      = 0;
+        $self->{Have_Plan}      = 1;
 
         # $self->_output_plan($max) unless $self->no_header;
     }
